searchData={"items":[{"type":"module","title":"FastMath.Combinatorics","doc":"`FastMath.Combinatorics` provides fast and efficient combinatorics functions.\n\nIt includes implementations for factorials, permutations, combinations, and\nother fundamental combinatorics operations.","ref":"FastMath.Combinatorics.html"},{"type":"function","title":"FastMath.Combinatorics.combinations/2","doc":"Calculates combinations ( C(n, r) = \frac{n!}{r!(n-r)!} ).","ref":"FastMath.Combinatorics.html#combinations/2"},{"type":"function","title":"Parameters - FastMath.Combinatorics.combinations/2","doc":"- `n` - An integer representing the total number of items.\n- `r` - An integer representing the number of selected items, ( r leq n ).","ref":"FastMath.Combinatorics.html#combinations/2-parameters"},{"type":"function","title":"Returns - FastMath.Combinatorics.combinations/2","doc":"The number of combinations.","ref":"FastMath.Combinatorics.html#combinations/2-returns"},{"type":"function","title":"Examples - FastMath.Combinatorics.combinations/2","doc":"iex> FastMath.Combinatorics.combinations(5, 3)\n    10","ref":"FastMath.Combinatorics.html#combinations/2-examples"},{"type":"function","title":"FastMath.Combinatorics.factorial/1","doc":"Calculates the factorial of `n`. Uses `permutations`","ref":"FastMath.Combinatorics.html#factorial/1"},{"type":"function","title":"Parameters - FastMath.Combinatorics.factorial/1","doc":"- `n` - A non-negative integer.","ref":"FastMath.Combinatorics.html#factorial/1-parameters"},{"type":"function","title":"Returns - FastMath.Combinatorics.factorial/1","doc":"The factorial of `n`.","ref":"FastMath.Combinatorics.html#factorial/1-returns"},{"type":"function","title":"Examples - FastMath.Combinatorics.factorial/1","doc":"iex> FastMath.Combinatorics.factorial(5)\n    120","ref":"FastMath.Combinatorics.html#factorial/1-examples"},{"type":"function","title":"FastMath.Combinatorics.generate_combinations/2","doc":"Efficiently generates all combinations of size `r` from the given list.\n\nUses symmetry to optimize generation when `r` is close to `n`.","ref":"FastMath.Combinatorics.html#generate_combinations/2"},{"type":"function","title":"Parameters - FastMath.Combinatorics.generate_combinations/2","doc":"- `list` - A list of items.\n- `r` - The size of each combination.","ref":"FastMath.Combinatorics.html#generate_combinations/2-parameters"},{"type":"function","title":"Returns - FastMath.Combinatorics.generate_combinations/2","doc":"A list of all possible combinations of size `r`.","ref":"FastMath.Combinatorics.html#generate_combinations/2-returns"},{"type":"function","title":"Examples - FastMath.Combinatorics.generate_combinations/2","doc":"iex> FastMath.Combinatorics.generate_combinations([1, 2, 3, 4], 3)\n    [[2, 3, 4], [1, 3, 4], [1, 2, 4], [1, 2, 3]]\n\n    iex> FastMath.Combinatorics.generate_combinations([1, 2, 3, 4], 1)\n    [[1], [2], [3], [4]]\n\n    iex> FastMath.Combinatorics.generate_combinations([1, 2, 3, 4], 0)\n    [[]]\n\n    iex> FastMath.Combinatorics.generate_combinations([1, 2, 3, 4], 4)\n    [[1, 2, 3, 4]]","ref":"FastMath.Combinatorics.html#generate_combinations/2-examples"},{"type":"function","title":"FastMath.Combinatorics.permutations/2","doc":"Calculates the number of permutations ( P(n, r) = n! / (n-r)! ) using an iterative approach.\n\nThis method avoids the computation of full factorials by directly calculating\nthe product of the necessary range ( n cdot (n-1) cdot ... cdot (n-r+1) ),\nmaking it more efficient for larger values of ( n ) and ( r ).","ref":"FastMath.Combinatorics.html#permutations/2"},{"type":"function","title":"Parameters - FastMath.Combinatorics.permutations/2","doc":"- `n` - The total number of items (integer).\n- `r` - The number of selected items (integer, ( r leq n )).","ref":"FastMath.Combinatorics.html#permutations/2-parameters"},{"type":"function","title":"Returns - FastMath.Combinatorics.permutations/2","doc":"The number of permutations as an integer.","ref":"FastMath.Combinatorics.html#permutations/2-returns"},{"type":"function","title":"Examples - FastMath.Combinatorics.permutations/2","doc":"iex> FastMath.Combinatorics.permutations(5, 3)\n    60\n\n    iex> FastMath.Combinatorics.permutations(6, 2)\n    30","ref":"FastMath.Combinatorics.html#permutations/2-examples"},{"type":"function","title":"FastMath.Combinatorics.variations/2","doc":"Calculates variations ( V(n, r) = n^r ).","ref":"FastMath.Combinatorics.html#variations/2"},{"type":"function","title":"Parameters - FastMath.Combinatorics.variations/2","doc":"- `n` - An integer representing the total number of items.\n- `r` - An integer representing the number of selected items.","ref":"FastMath.Combinatorics.html#variations/2-parameters"},{"type":"function","title":"Returns - FastMath.Combinatorics.variations/2","doc":"The number of variations.","ref":"FastMath.Combinatorics.html#variations/2-returns"},{"type":"function","title":"Examples - FastMath.Combinatorics.variations/2","doc":"iex> FastMath.Combinatorics.variations(2, 3)\n    8","ref":"FastMath.Combinatorics.html#variations/2-examples"},{"type":"extras","title":"FastMath.Combinatorics","doc":"# FastMath.Combinatorics\n\n`FastMath.Combinatorics` provides fast and efficient combinatorics functions for Elixir, including implementations for:\n\n- Factorials\n- Permutations\n- Combinations\n- Variations\n- Efficient generation of combinations from a list\n\nThe library is optimized for performance, using iterative methods, symmetry, and other techniques to minimize unnecessary computations.","ref":"readme.html"},{"type":"extras","title":"Features - FastMath.Combinatorics","doc":"- **Factorials**: Compute \\( n! \\) efficiently using permutations.\n- **Permutations**: Compute \\( P(n, r) = n! / (n-r)! \\) using an iterative approach.\n- **Combinations**: Compute \\( C(n, r) = n! / (r!(n-r)!) \\) directly without full factorials.\n- **Variations**: Compute \\( V(n, r) = n^r \\).\n- **Generate Combinations**: Efficiently generate all \\( r \\)-element combinations from a list, leveraging symmetry for optimization.","ref":"readme.html#features"},{"type":"extras","title":"Installation - FastMath.Combinatorics","doc":"Add `fastmath_combinatorics` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fastmath_combinatorics, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - FastMath.Combinatorics","doc":"Documentation can be generated using [ExDoc](https://github.com/elixir-lang/ex_doc) and is available at [HexDocs](https://hexdocs.pm).\n\nTo generate the docs locally, run:\n\n```bash\nmix docs\n```\n\nOnce published, the documentation will be available at [HexDocs](https://hexdocs.pm/fastmath_combinatorics).","ref":"readme.html#documentation"},{"type":"extras","title":"Examples - FastMath.Combinatorics","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Factorial - FastMath.Combinatorics","doc":"Calculate the factorial of a number:\n```elixir\niex> FastMath.Combinatorics.factorial(5)\n120\n```","ref":"readme.html#factorial"},{"type":"extras","title":"Permutations - FastMath.Combinatorics","doc":"Calculate the number of permutations \\( P(n, r) \\):\n```elixir\niex> FastMath.Combinatorics.permutations(5, 3)\n60\n```","ref":"readme.html#permutations"},{"type":"extras","title":"Combinations - FastMath.Combinatorics","doc":"Calculate the number of combinations \\( C(n, r) \\):\n```elixir\niex> FastMath.Combinatorics.combinations(5, 3)\n10\n```","ref":"readme.html#combinations"},{"type":"extras","title":"Variations - FastMath.Combinatorics","doc":"Calculate the number of variations \\( V(n, r) \\):\n```elixir\niex> FastMath.Combinatorics.variations(2, 3)\n8\n```","ref":"readme.html#variations"},{"type":"extras","title":"Generate Combinations - FastMath.Combinatorics","doc":"Generate all \\( r \\)-element combinations from a list:\n```elixir\niex> FastMath.Combinatorics.generate_combinations([1, 2, 3, 4], 3)\n[[1, 2, 3], [1, 2, 4], [1, 3, 4], [2, 3, 4]]\n```","ref":"readme.html#generate-combinations"},{"type":"extras","title":"Contributing - FastMath.Combinatorics","doc":"Contributions are welcome! If you have ideas for improvements or additional functionality, feel free to submit a pull request or open an issue.","ref":"readme.html#contributing"},{"type":"extras","title":"License - FastMath.Combinatorics","doc":"This project is licensed under the [MIT License](LICENSE).","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}